import qrcode
from io import BytesIO
from django.core.files import File
from .models import Quotation

def generate_qr_code(quotation_id, qr_data):
    try:
        # Convert QR data to string
        qr_string = "\n".join([f"{key}: {value}" for key, value in qr_data.items()])
        
        # Generate QR code image
        qr = qrcode.QRCode(
            version=1,
            error_correction=qrcode.constants.ERROR_CORRECT_L,
            box_size=10,
            border=4,
        )
        qr.add_data(qr_string)
        qr.make(fit=True)
        qr_img = qr.make_image(fill_color="black", back_color="white")
        
        # Save the QR code image to a BytesIO buffer
        buffer = BytesIO()
        qr_img.save(buffer, format='PNG')
        
        # Create a Quotation object and save it to the database
        quotation = Quotation.objects.get(pk=quotation_id)
        
        # Save the QR code image to the Quotation object
        quotation.qr_code.save(f"quotation_{quotation_id}_qr.png", File(buffer))
        
        return True, None  # QR code saved successfully
    except Exception as e:
        return False, e  # Error occurred while saving QR code

# Usage example:
# Replace `quotation_id` with the actual ID of the quotation
# quotation_id = 1  # Example ID
# qr_data = {
#     "invoice_number": "INV-12345",
#     "amount": 100.00,
#     "customer_name": "John Doe",
#     # Add more invoice qr_data as needed
# }
# success, error = generate_qr_code(quotation_id, qr_data)
# if success:
#     print("QR code saved successfully.")
# else:
#     print(f"Error saving QR code: {error}")
